@@ -12,15 +12,14 @@ CLI_COMMANDS_HELP = {
                 ** Tips: 1) The parameter may be inherited from the parent contexts or owned by the given context.\n
                 KEY: The identifier of the parameter. It may also be provided using the '--key' option.\n
                 """,
-        'history': """Return the revision history of parameter.\n
-                ** Tips: 1) The parameter may be inherited from the parent contexts or owned by the given context.\n
-                KEY: The identifier of the parameter. It may also be provided using the '--key' option.\n
-                """,
-
         'delete': """Delete a parameter from a context.\n
                 ** Tips: 1) The inherited parameters cannot be deleted. The context must be the owner of the parameter or a not found error will be returned. 2) Multiple parameters may be deleted at once using the '--input' option.\n         
                 KEY: The identifier of the parameter to be deleted. It may also be provided using the '--key' option.\n
                 """,
+        'history': """Return the revision history of parameter.\n
+                ** Tips: 1) The parameter may be inherited from the parent contexts or owned by the given context.\n
+                KEY: The identifier of the parameter. It may also be provided using the '--key' option.\n
+                """,
     },
     'secret': {
         'add': """Add a secret to a context, or update a secret if it is already existing in the context.\n
@@ -39,6 +38,11 @@ CLI_COMMANDS_HELP = {
                 ** Tips: 1) The inherited secrets cannot be deleted. The context must be the owner of the secret or a not found error will be returned. 2) Multiple secrets may be deleted at once using the '--input' option.\n         
                 KEY: The identifier of the secret to be deleted. It may also be provided using the '--key' option.\n
                 """,
+        'history': """Return the revision history of secret.\n
+                ** Tips: 1) The secret may be inherited from the parent contexts or owned by the given context.\n
+                KEY: The identifier of the secret. It may also be provided using the '--key' option.\n
+                """,
+
     },
     'template': {
         'add': """Add a template to a context, or update the contents if it is already existing in the context.\n
@@ -56,6 +60,10 @@ CLI_COMMANDS_HELP = {
                 ** Tips: 1) The inherited template cannot be deleted. The context must be the owner of the secret or a not found error will be returned. 2) Multiple templates may be deleted at once using the '--input' option.\n
                 KEY: The identifier of the template to be deleted. It may also be provided using the '--key' option.\n
                 """,
+        'history': """Return the revision history of template.\n
+                ** Tips: 1) The template may be inherited from the parent contexts or owned by the given context.\n
+                KEY: The identifier of the template. It may also be provided using the '--key' option.\n
+                """,
         'render': """Render templates in a context.\n
                     """,
         },
@@ -76,33 +84,32 @@ CLI_COMMANDS_HELP = {
         'init': """Initialize DSO configuration for the working directory.\n
                 ** Tips: 1) Use --input to load connfiguration from a file.\n
                 The option '--working-dir' can be used to specify a different working directory than the current directory where dso is running in.\n
-                """
-
-
-
-    }
+                """,
+    },
 }
 
 CLI_COMMANDS_SHORT_HELP = {
     'version': "Display versions.",
     'parameter': {
-        'list': "List parameters added to the application.",
+        'list': "List parameters available to the application.",
         'add': "Add one or multiple parameters to the application.",
         'get': "Get the value of a parameter.",
-        'delete': "Delete one or multiple parameters from an application.",
-
+        'delete': "Delete one or multiple parameters from the application.",
+        'history': "Get the revision history of a parameter.",
     },
     'secret': {
-        'list': "List secrets added to the application.",
+        'list': "List secrets available to the application.",
         'add': "Add one or multiple secrets to the application.",
         'get': "Get the value of a secret.",
-        'delete': "Delete one or multiple secrets from an application.",
+        'delete': "Delete one or multiple secrets from the application.",
+        'history': "Get the revision history of a secret.",
     },
     'template': {
-        'list': "List templates added to the application.",
+        'list': "List templates available to the application.",
         'add': "Add a template to the application.",
         'get': "Get the content of a template.",
         'delete': "Delete one or multiple templates from the application.",
+        'history': "Get the revision history of a template.",
         'render': "Render templates using parameters in a context.",
     },
     'package': {
@@ -151,6 +158,7 @@ CLI_PARAMETERS_HELP = {
     'secret': {
         'key': "The key of the secret",
         'value': "The value for the secret",
+        'decrypt': "Decrypt the secret value.",
         'query_values': "Include secret values in the output.",
         'uninherited': "Select only secrets which are specific to the gievn context, i.e. not inherited from the parent contexts.",
         'revision': "The revision ID whose value to be fetched.",
@@ -166,6 +174,7 @@ CLI_PARAMETERS_HELP = {
         'recursive' : "Add files recursively.",
         'uninherited': "Select only templates which are specific to the gievn context, i.e. not inherited from the parent contexts.",
         'include_contents': "Include template contenets in the output. ",
+        'history': "Get the revision history of the template.",
 
     },
     'config': {
