@@ -74,9 +74,10 @@ def format_data(data, query, format):
             for i in range(0, len(result)):
                 item = result[i]
                 if isinstance(item, dict):
-                    valuesStr = '\t'.join(map(str, list(item.values())))
+                    ### the map also treats None values
+                    valuesStr = '\t'.join(map(lambda x: str(x) if not x is None else '', list(item.values())))
                 else:
-                    valuesStr = str(item)
+                    valuesStr = str(item) if not item is None else ''
                 outputStream += f"{valuesStr}"
                 if i < len(result)-1: outputStream += '\n'
         elif isinstance(result, dict):
@@ -88,17 +89,17 @@ def format_data(data, query, format):
                     for i in range(0, len(childList)):
                         item = childList[i]
                         if isinstance(item, dict):
-                            valuesStr = '\t'.join(map(str, list(item.values())))
+                            valuesStr = '\t'.join(map(lambda x: str(x) if not x is None else '', list(item.values())))
                         else:
-                            valuesStr = str(item)
+                            valuesStr = str(item) if not item is None else ''
                         outputStream += f"{valuesStr}"
                         if i < len(childList)-1: outputStream += '\n'
                 else:
-                    outputStream = '\t'.join(map(str, list(result.values())))
+                    outputStream = '\t'.join(map(lambda x: str(x) if not x is None else '', list(result.values())))
             elif len(keys) > 1:
-                outputStream = '\t'.join(map(str, list(result.values())))
+                outputStream = '\t'.join(map(lambda x: str(x) if not x is None else '', list(result.values())))
         else:
-            outputStream += str(result)
+            outputStream += str(result) if not result is None else ''
         
         return outputStream
 
