@@ -32,7 +32,6 @@ _default_config = {
             'id': '',
             'spec': {}
         },
-        'allowStageTemplates': False,
         'render': {}
     }
 }
@@ -282,10 +281,6 @@ class ConfigManager:
             raise DSOException(MESSAGES['ProviderNotSet'].format('Template'))
         return result
 
-    @property
-    def allow_stage_templates(self):
-        return self.merged_config['template']['allowStageTemplates'] in [True, 'yes', 'Yes', 'true', 'True']
-
     def parameter_spec(self, key=None):
         try:
             result = self.merged_config['parameter']['provider']['spec']
