@@ -7,6 +7,8 @@ from .constants import *
 from .exceptions import *
 
 
+REGEX_PATTERN  = r"^[a-zA-Z][.a-zA-Z0-9_-]*[a-zA-Z0-9]$"
+
 class ParameterProvider(StoreProvider):
     def list(self, project, application, stage, uninherited=False, filter=None):
         raise NotImplementedError()
@@ -23,11 +25,13 @@ class ParameterProvider(StoreProvider):
 class ParameterManager():
 
     def validate_key(self, key):
-        Logger.info("Start validating parameter key...")
-        Logger.debug(f"Validating: key={key}")
-        pattern = REGEX_PATTERNS['parameter_key']
-        if not re.match(pattern, key):
-            raise DSOException(MESSAGES['InvalidKeyPattern'].format(key, pattern))
+        Logger.info(f"Validating parameter key '{key}'...")
+        if not key:
+            raise DSOException(MESSAGES['KeyNull'])
+        if key == 'dso' or key.startswith('dso.'):
+            raise DSOException(MESSAGES['DSOReserverdKey'].format(key))
+        if not re.match(REGEX_PATTERN, key):
+            raise DSOException(MESSAGES['InvalidKeyPattern'].format(key, REGEX_PATTERN))
         if '..' in key:
             raise DSOException(MESSAGES['InvalidKeyStr'].format(key, '..'))
             
