@@ -10,7 +10,7 @@ from dsocli.constants import *
 from dsocli.dict_utils import set_dict_value
 from dsocli.contexts import Contexts
 from dsocli.aws_utils import *
-
+from dsocli.settings import *
 
 _default_spec = {
     'prefix': '/dso/v1/templates',
@@ -34,22 +34,12 @@ class AwsSsmTemplateProvider(TemplateProvider):
     def __init__(self):
         super().__init__(_settings['id'])
 
-###--------------------------------------------------------------------------------------------
+
 
     def get_prefix(self):
         return Configs.template_spec('prefix')
 
-###--------------------------------------------------------------------------------------------
-    ### AWS SSM Parameyer store does not allow {{}}
-    def escape_curly_brackets(self, contents):
-        return contents.replace('{{', r'\{\{').replace('}}', r'\}\}')
 
-###--------------------------------------------------------------------------------------------
-
-    def unescape_curly_brackets(self, contents):
-        return contents.replace(r'\{\{', '{{').replace(r'\}\}', '}}')
-
-###--------------------------------------------------------------------------------------------
 
     def list(self, project, application, stage, uninherited=False, include_contents=False, filter=None):
         templates = load_context_ssm_parameters(project, application, stage, 'StringList', prefix=self.get_prefix(), uninherited=uninherited)
@@ -78,13 +68,13 @@ class AwsSsmTemplateProvider(TemplateProvider):
 
         return result
 
-###--------------------------------------------------------------------------------------------
+
 
     def add(self, project, application, stage, key, contents, render_path=None):
         if len(contents) > 4096:
             raise DSOException(f"This template provider does not support templates larger than 4KB.")
-        if not Stages.is_default(stage) and not Configs.allow_stage_templates:
-            raise DSOException(f"Templates may not be added to stage scopes, as the feature is currently disabled. It can be enabled using 'allowStageTemplates' in the DSO application configuration.")
+        if not Stages.is_default(stage) and not ALLOW_STAGE_TEMPLATES:
+            raise DSOException(f"Templates may not be added to stage scopes, as the feature is currently disabled. It may be enabled using 'ALLOW_STAGE_TEMPLATES' in the DSO global settings.")
         Logger.debug(f"Checking SSM template overwrites: project={project}, application={application}, stage={stage}, key={key}")
         assert_ssm_parameter_no_namespace_overwrites(project, application, stage, key, prefix=self.get_prefix())
         Logger.debug(f"Locating SSM template: project={project}, application={application}, stage={stage}, key={key}")
@@ -93,7 +83,7 @@ class AwsSsmTemplateProvider(TemplateProvider):
             raise DSOException(f"Failed to add template '{key}' becasue becasue the key is not available in the given context: project={project}, application={application}, stage={Stages.shorten(stage)}")
         path = get_ssm_path(project, application, stage=stage, key=key, prefix=self.get_prefix())
         Logger.info(f"Adding SSM template: path={path}")
-        response = ssm.put_parameter(Name=path, Value=self.escape_curly_brackets(contents), Type='StringList', Overwrite=True)
+        response = ssm.put_parameter(Name=path, Value=escape_curly_brackets(contents), Type='StringList', Overwrite=True)
         return {
                 'Key': key,
                 'Scope': Contexts.translate_context(project, application, stage),
@@ -106,7 +96,7 @@ class AwsSsmTemplateProvider(TemplateProvider):
                 # 'Path': path,
             }
 
-###--------------------------------------------------------------------------------------------
+
 
     def get(self, project, application, stage, key, revision=None):
         Logger.debug(f"Locating SSM template: project={project}, application={application}, stage={stage}, key={key}")
@@ -129,7 +119,7 @@ class AwsSsmTemplateProvider(TemplateProvider):
                     'Origin': found['Origin'],
                     'User': templates[0]['LastModifiedUser'],
                     'Path': found['Name'],
-                    'Contents': self.unescape_curly_brackets(templates[0]['Value']),
+                    'Contents': unescape_curly_brackets(templates[0]['Value']),
                     }
         else:
             ### get specific revision
@@ -144,12 +134,12 @@ class AwsSsmTemplateProvider(TemplateProvider):
                     'Origin': found['Origin'],
                     'User': templates[0]['LastModifiedUser'],
                     'Path': found['Name'],
-                    'Contents': self.unescape_curly_brackets(templates[0]['Value']),
+                    'Contents': unescape_curly_brackets(templates[0]['Value']),
                     }
 
         return result
 
-###--------------------------------------------------------------------------------------------
+
 
     def history(self, project, application, stage, key, include_contents=False):
         Logger.debug(f"Locating SSM template: project={project}, application={application}, stage={stage}, key={key}")
@@ -172,7 +162,7 @@ class AwsSsmTemplateProvider(TemplateProvider):
                     # 'Origin': found['Origin'],
                     'User': template['LastModifiedUser'],
                     # 'Path': found['Name'],
-                    'Contents': self.unescape_curly_brackets(template['Value']),
+                    'Contents': unescape_curly_brackets(template['Value']),
                 } for template in parameters]
             }
         else:
@@ -190,7 +180,7 @@ class AwsSsmTemplateProvider(TemplateProvider):
 
         return result
 
-###--------------------------------------------------------------------------------------------
+
 
     def delete(self, project, application, stage, key):
         Logger.debug(f"Locating SSM template: project={project}, application={application}, stage={stage}, key={key}")
@@ -212,8 +202,8 @@ class AwsSsmTemplateProvider(TemplateProvider):
                 # 'Path': found['Name'],
                 }
 
-###--------------------------------------------------------------------------------------------
-###--------------------------------------------------------------------------------------------
-###--------------------------------------------------------------------------------------------
+
+
+
 
 Providers.register(AwsSsmTemplateProvider())
