@@ -13,6 +13,9 @@ from .dict_utils import merge_dicts, deflatten_dict
 from .exceptions import DSOException
 from .stages import Stages
 
+
+REGEX_PATTERN = r"^[a-zA-Z][./a-zA-Z0-9_-]*[a-zA-Z0-9]$"
+
 class TemplateProvider(StoreProvider):
     def list(self, project, application, stage, uninherited=False, include_contents=False, filter=None):
         raise NotImplementedError()
@@ -33,11 +36,13 @@ class TemplateManager():
         return Configs.working_dir
 
     def validate_key(self, key):
-        Logger.info("Start validating template key...")
-        Logger.debug(f"Validating: key={key}")
-        pattern = REGEX_PATTERNS['template_key']
-        if not re.match(pattern, key):
-            raise DSOException(MESSAGES['InvalidKeyPattern'].format(key, pattern))
+        Logger.info(f"Validating template key '{key}'...")
+        if not key:
+            raise DSOException(MESSAGES['KeyNull'])
+        if key == 'dso' or key.startswith('dso.'):
+            raise DSOException(MESSAGES['DSOReserverdKey'].format(key))
+        if not re.match(REGEX_PATTERN, key):
+            raise DSOException(MESSAGES['InvalidKeyPattern'].format(key, REGEX_PATTERN))
         ### the regex does not check adjacent special chars
         if '..' in key:
             raise DSOException(MESSAGES['InvalidKeyStr'].format(key, '..'))
